@@ -286,14 +286,16 @@ QString PackageDisplayWidget::selectedPackage() const
 QString PackageDisplayWidget::packageForRow(int row) const
 {
 	// TODO this relies on the package name column to be present and filled
-	int nameColumn = columnForName("Name");
+	// translation _must_ match the translation of the column title!
+	int nameColumn = columnForName(tr("Name"));
 	QString packageName = item(row, nameColumn)->text();
 	return packageName;	
 }
 
 bool PackageDisplayWidget::scoreColumnVisible() const
 {
-	int scoreColumn = columnForName("Score");
+	// translation _must_ match the translation of the column title!
+	int scoreColumn = columnForName(tr("Score"));
 	if (scoreColumn == -1)
 		return false;
 	else 
