@@ -93,7 +93,7 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 {
 	typedef ept::apt::Apt Apt;
 	const Apt& packages = _pProvider->apt();
-	if (searchDescr)
+	if (searchDescr)	// perform a full text search within the descriptions
 	{
 		try {
 			Xapian::Enquire enq(_pProvider->xapian());
@@ -116,8 +116,8 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 				enq.set_query(Xapian::Query(Xapian::Query::OP_AND_NOT, inc, exc));
 			}
 	
-			// Get the 15k best results out of Xapian
-			Xapian::MSet matches = enq.get_mset(0, 15000);
+			// Get the 25k best results out of Xapian
+			Xapian::MSet matches = enq.get_mset(0, 25000);
 			for (Xapian::MSetIterator i = matches.begin(); i != matches.end(); ++i)
 			{
 				// Filter out results that apt doesn't know
@@ -135,37 +135,48 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 				e.get_context().c_str());
 		}
 	}
-	// search in the package names in both cases (since Xapian-search seems not to search within the title) 
+	// search in the package names in both cases (since Xapian-search cannot search within the title,
+	// it can only search for the title starting with the given word (by XPterm*), but that does not find
+	// the search term occuring at the end of the title (e.g. search term "apt" in "python-apt")
+	for ( Apt::iterator it = packages.begin(); it != packages.end(); ++it )
 	{
-		for ( Apt::iterator it = packages.begin(); it != packages.end(); ++it )
+		if (result.find(*it) != result.end())	// if the package is already in the result list
+			continue;
+		QString name = toQString(*it);
+		// will be set to false when one of the include patterns was not found in the package description
+		bool included = true;
+		// check if each included pattern occurs in the package
+		for (QStringList::const_iterator jt = includePatterns.begin(); jt != includePatterns.end(); ++jt)
 		{
-			QString name = toQString(*it);
-			// holds if the search matches the package
-			bool included = true;
-			// check if each included pattern occurs in the package
-			for (QStringList::const_iterator jt = includePatterns.begin(); jt != includePatterns.end(); ++jt)
+			if ( !searchString(name, *jt, false, false) )
 			{
-				if ( !searchString(name, *jt, false, false) )
-				{
-					included = false;
-					break;
-				}
+				included = false;
+				break;
 			}
-			if (!included)
-				continue;
-			// check if each excluded pattern does not occur in the package
-			for (QStringList::const_iterator jt = excludePatterns.begin(); jt != excludePatterns.end(); ++jt)
-			{
-				if ( !searchString(name, *jt, false, false) )
-				{
-					included = false;
-					break;
-				}
-			}
-			if (included)
-				result.insert(*it);
 		}
+		if (included)
+			result.insert(*it);
 	}
+
+	for (std::set<string>::iterator it = result.begin(); it != result.end();) 
+	{
+		bool erase = false;
+		QString name = toQString(*it);
+		for (QStringList::const_iterator jt = excludePatterns.begin(); jt != excludePatterns.end(); ++jt)
+		{
+			if ( searchString(name, *jt, false, false) )
+			{
+				erase = true;
+				break;
+			}
+		}
+		if (erase) // we cannot erase the current iterator without causing harm, so we do it a little 
+			// more complicated
+			result.erase(it++);
+		else
+			++it;
+	}
+
 	return result.empty();
 }
 
