@@ -50,7 +50,7 @@ Plugin* AptPluginFactory::createPlugin(const string& name) const
 	}
 	if (name=="AptActionPlugin")
 	{
-		return new AptActionPlugin();
+		return new AptActionPlugin(_pMediator);
 	}
 	if (name=="PackageStatusPlugin")
 	{
