@@ -33,7 +33,7 @@ IPackage::BorderList IPackage::getPackageList(const QString& s)
 	uint inPar=0;
 	// a simple parser...
 	currentPair.first=0;
-	for (uint i=0; i<s.length(); ++i)
+	for (int i=0; i<s.length(); ++i)
 	{
 		if (inWord)
 		{
