@@ -8,13 +8,14 @@
 #include <unistd.h>		// for getuid and geteuid
 #include <sys/types.h>	//
 
+#include "debtagsplugincontainer.h"
+
 #include <wibble/operators.h>
 
+#undef slots
 #include <xapian.h>
 
 
-#include "debtagsplugincontainer.h"
-
 // NUtil
 #include "helpers.h"
 
@@ -82,6 +83,7 @@ DebtagsPluginContainer::DebtagsPluginContainer()
 	_pRelatedPlugin = 0;
 	_pDebtagsPlugin = 0;
 	_pSettingsWidget = 0;
+	_pVocabularyModel = 0;
 	addPlugin("DebtagsPlugin");
 	addPlugin("RelatedPlugin");
 	
