@@ -21,6 +21,13 @@
 
 using namespace std;
 
+namespace NTagModel
+{
+	class VocabularyModel;
+	class FilterHiddenProxyModel;
+}
+
+
 /** @brief Widget used to let the user select facets to be hidden and shown.
   *
   * @author Benjamin Mesing
@@ -28,17 +35,17 @@ using namespace std;
 class DebtagsSettingsWidget : public QWidget, public Ui::DebtagsSettingsWidget
 {
 Q_OBJECT
+	typedef NTagModel::FilterHiddenProxyModel FilterHiddenProxyModel;
+	NTagModel::VocabularyModel* _pModel;
+	FilterHiddenProxyModel* _pShownModel;
+	FilterHiddenProxyModel* _pHiddenModel;
 public:
 	/**
 	  * @param hiddenFacets the facets which are selected to be hidden	
 	  */
-	DebtagsSettingsWidget(const set<string>& hiddenFacets, QWidget *parent = 0, const char *name = 0);
+	DebtagsSettingsWidget(NTagModel::VocabularyModel* pModel, QWidget *parent = 0, const char *name = 0);
 	~DebtagsSettingsWidget();
-	/** @brief This returns all facets that where selected to be hidden. */
-	set<string> hiddenFacets();
-	/** @brief This returns all facets that where selected to be shown. */
-	set<string> shownFacets();
-protected slots:
+protected Q_SLOTS:
 	/** @brief The button to add facets to the hidden facets was clicked. */
 	void on__pAddButton_clicked();
 	/** @brief The button to remove facets from the hidden facets was clicked. */
