@@ -11,6 +11,8 @@
 //
 #include "filterselectedproxymodel.h"
 
+#include <QDebug>
+
 // NTagModel
 #include "vocabularymodelrole.h"
 
@@ -31,8 +33,10 @@ FilterSelectedProxyModel::~FilterSelectedProxyModel()
 bool FilterSelectedProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
 {
 	QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
-	if (sourceModel()->data(index, TypeRole).toInt() == FacetTypeItem)
+	if (sourceModel()->data(index, TypeRole).toInt() == FacetTypeItem) 
+	{
 		return true;
+	}
 	bool isSelected = sourceModel()->data(index, SelectedRole).toBool();
 	return isSelected == _includeSelected;
 }
