@@ -45,16 +45,6 @@ public:
 	/** @brief Sets _includeSelected. */
 	void setIncludeSelected(bool includeSelected)	{ _includeSelected = includeSelected; }
 	bool filterAcceptsRow ( int sourceRow, const QModelIndex & sourceParent ) const;
-	// TODO: debug
-/*	virtual QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const
-	{
-		if (role == Qt::DisplayRole)
-		{
-			qDebug("[FilterSelectedProxyModel::data()] row: %d column: %d", index.row(), index.column());
-			qDebug("[FilterSelectedProxyModel::data()] tag name " + sourceModel()->data(mapToSource(index), role).toString());
-		}
-		return QSortFilterProxyModel::data(index, role);
-	}*/
 };
 
 }
