@@ -20,6 +20,8 @@
 class QAbstractProxyModel;
 class QContextMenuEvent;
 
+class TreeFilterModel;
+
 namespace NTagModel
 {
 
@@ -39,6 +41,7 @@ Q_OBJECT
 	NTagModel::FilterSelectedProxyModel _selectedProxyModel;
 	TagListProxyModel* _pTagListProxyModel;
 	VocabularyModel* _pModel;
+	TreeFilterModel* _pTreeFilterModel;
 public:
 	SelectedTagsView(QWidget * parent = 0);
 	~SelectedTagsView();
@@ -47,7 +50,7 @@ public:
 	  * @param pModel must be a VocabularyModel.
 	  */
 	virtual void setModel(QAbstractItemModel* pModel);
-protected slots:
+protected Q_SLOTS:
 	virtual void onItemDoubleClicked(const QModelIndex& index);
 	virtual void contextMenuEvent(QContextMenuEvent* pEvent);
 protected:
