@@ -3,6 +3,7 @@
 #include <assert.h>
 
 #include <qcheckbox.h>
+#include <QDir>
 #include <qfileinfo.h>
 #include <qlineedit.h>
 #include <QMainWindow>
@@ -122,19 +123,29 @@ void FilenamePlugin::updateInformationWidget(const string& package)
 	_pFileView->clear();
 	// prevent showing of information if we have only slow access to the file list (i.e. 
 	// apt-file
-	if (hasFastFilelist(package))	
+	if (isInstalled(package))	
 	{
 	 	onShowRequested();
+	 	_pFileView->setShowButtonEnabled(false);
 	}
 	else
 	{
-		_pFileView->setErrorMessage
-		(
-			"<font color=#606060>For packages <b>not installed</b>, the files are not shown "
-			"by default. This is because listing those will take some time.<br>"
-			"Please click the <b>&quot;Show&quot;</b> button to show the filelist for the "
-			"selected package.</font>" 
-		);
+		if (aptFileAvailable())
+		{
+			_pFileView->setErrorMessage
+			(
+				tr("<font color=#606060>For packages <b>not installed</b>, the file list is not shown "
+				"by default. This is because retreiving the file list will take some time.<br>"
+				"Please click the <b>&quot;Show&quot;</b> button to show the filelist for the "
+				"selected package.</font>")
+			);
+		 	_pFileView->setShowButtonEnabled(true);
+		}
+		else
+		{
+			_pFileView->setErrorMessage( aptFileMissingErrorMsg(toQString(package)) );
+		 	_pFileView->setShowButtonEnabled(false);
+		}
 	}
 }
 
@@ -165,7 +176,7 @@ QWidget* FilenamePlugin::inputWidget() const
 
 QString FilenamePlugin::inputWidgetTitle() const 
 { 
-	return QString("Filenames"); 
+	return tr("Filenames"); 
 };
 
 
@@ -186,19 +197,34 @@ bool FilenamePlugin::isInactive() const
 // Information Helper Methods
 /////////////////////////////////////////////////////
 
-bool FilenamePlugin::hasFastFilelist(const string& packageName)
+QFileInfo FilenamePlugin::getFileListFileName(const string& packageName)
 {
 	QFileInfo packageList("/var/lib/dpkg/info/" + toQString(packageName) + ".list");
-	return (packageList.isReadable());	// if the package is installed i.e. its list is in the .list file
+	if (packageList.isReadable()) 
+		return packageList;
+	QDir pkgInfoDir("/var/lib/dpkg/info/");
+	QStringList filter;
+	filter.append(toQString(packageName) + "*.list");
+	pkgInfoDir.setNameFilters(filter);
+	QFileInfoList entries = pkgInfoDir.entryInfoList();
+	if (entries.isEmpty())
+		return QFileInfo();
+	return entries.first();
 }
 
+bool FilenamePlugin::isInstalled(const string& packageName)
+{
+	return getFileListFileName(packageName).isReadable();	// if the package is installed
+}
+
+
 QStringList FilenamePlugin::filesForPackage(const string& packageName) throw (NoInformationException)
 {
 	QStringList files;	// the files in the given package
-	QFileInfo packageList("/var/lib/dpkg/info/" + toQString(packageName) + ".list");
-	if (packageList.isReadable())	// if the package is installed i.e. its list is in the .list file
+	if (isInstalled(packageName))	// if the package is installed
 	{
-		string filename = "/var/lib/dpkg/info/" + packageName + ".list";
+		QFileInfo fileInfo = getFileListFileName(packageName);
+		string filename = toString(fileInfo.absoluteFilePath());
 		ifstream file(filename.c_str());
 		while (file)
 		{
@@ -218,7 +244,7 @@ QStringList FilenamePlugin::filesForPackage(const string& packageName) throw (No
 				qDebug("The mutex was locked\n");
 				return QStringList();
 			}
-			_pProvider->reportBusy(this, "Querying database for installed files.");
+			_pProvider->reportBusy(this, tr("Querying database for file list"));
 			_pProvider->setEnabled(false);
 			_pProcess = new NApplication::RunCommandForOutput("apt-file");
  			connect(_pProcess, SIGNAL(processExited(RunCommandForOutput*)), SLOT(onFilelistProcessExited()));
@@ -230,13 +256,7 @@ QStringList FilenamePlugin::filesForPackage(const string& packageName) throw (No
 		}
 		else
 		{
-			throw NoInformationException(
-				 QObject::tr("<p>No information for this package could be retrieved.\n"
-				"If <tt>apt-file</tt> is not installed, the list of files is only available for "
-				"installed packages.</p>"
-				"To get apt-file fetch it via <tt>apt-get install apt-file</tt> and run "
-				"<tt>apt-file update</tt> after this.")
-			);
+			throw NoInformationException( aptFileMissingErrorMsg(toQString(packageName)) );
 		}
 	}
 	return files;	// return the list of files, or an empty list if a process was launched
@@ -246,7 +266,7 @@ bool FilenamePlugin::fixEntry(QString& entry, const QString& packageName)
 {
 	if (!entry.startsWith(packageName+":"))
 		return false;
-	entry.replace(packageName+": ", "/");
+	entry.remove(packageName+": ");
 	return true;
 }
 
@@ -282,7 +302,7 @@ void FilenamePlugin::onShowRequested()
 		QStringList files = filesForPackage(toString(_currentPackage));
 		NExtStd::for_each(files.begin(), files.end(), &FilenameView::addEntry, _pFileView);
 	}
-	catch (NoInformationException e)	// this should not happen, only for security reasons
+	catch (NoInformationException e)
 	{
 		_pFileView->setErrorMessage(e._errorMessage);
 	}
@@ -295,7 +315,7 @@ void FilenamePlugin::onShowRequested()
 
 void FilenamePlugin::onInputTextChanged(const QString&)
 {
-	_pProvider->mainWindow()->statusBar()->showMessage( tr("delayed evaluation - waiting for further input") );
+	_pProvider->mainWindow()->statusBar()->showMessage( tr("delayed evaluation - waiting for further input"), _delayTime );
 	_pDelayTimer->start(_delayTime);
 }
 
@@ -402,4 +422,13 @@ bool FilenamePlugin::aptFileAvailable()
 }
 
 
+QString FilenamePlugin::aptFileMissingErrorMsg(QString packageName)
+{
+	return tr("<font color=#606060><p>File list for <b>") + packageName + tr("</b> not available.</p>"
+	"<p>For displaying the file list for not-installed packages, the \"apt-file\" "
+	"package is required. Please install \"apt-file\" and "
+	"retrieve the latest file database by running  <tt>apt-file update</tt>.</p></font>");
+}
+
+
 }	// namespace NPlugin
