@@ -48,7 +48,7 @@ FilenameView::~FilenameView()
 
 void FilenameView::viewFile(QString filename)
 {
-	_pProvider->statusBar()->showMessage("Trying to view " + filename, 4000);
+	_pProvider->statusBar()->showMessage(tr("Trying to view ") + filename, 4000);
 	QFileInfo seeInfo(_seeCommand );
 	if ( !seeInfo.isExecutable() )
 	{
@@ -56,7 +56,7 @@ void FilenameView::viewFile(QString filename)
 			_seeCommand + tr(" not available"), 
 			tr("The <tt>") + _seeCommand + tr("</tt> command is not available.\n"
 				"Please make sure that the <tt>mime-support</tt> package is installed "
-				"and that you have permission to execute <tt>") + _seeCommand + "</tt>."
+				"and that you have permission to execute <tt>") + _seeCommand + tr("</tt>.")
 		);
 		return;
 	}
@@ -94,15 +94,15 @@ void FilenameView::onProcessExited(QProcess* pProcess )
 			pProcess->deleteLater();
 			_pProvider->reportError( tr("Error viewing file"), tr("Unable to view file ") + filename
 				+ tr("\nTried <tt>") + _seeCommand + " " + filename + tr("</tt> and\n<tt>") + _seeCommand + " " + 
-				TEXT_PLAIN_PREFIX + filename +"</tt>" );
+				TEXT_PLAIN_PREFIX + filename + "</tt>" );
 		//	qDebug("Error launching see " + pItem->text(0));
 		}
 		else
 		{
 			_seeCommands[pProcess] = make_pair(filename, true);
-			_pProvider->statusBar()->showMessage("Retrying to view " + filename + " with mimetype text/plain",
+			_pProvider->statusBar()->showMessage(tr("Retrying to view ") + filename + tr(" with mimetype text/plain"),
 				 4000);
-			qDebug((QString("retrying process ") + filename).toAscii());
+			qDebug("%s", (QString("retrying process ") + filename).toAscii().data());
 			QStringList arguments;
 			arguments.push_back(TEXT_PLAIN_PREFIX+filename);
 			_processContainer.start(pProcess, "see", arguments);
@@ -111,7 +111,7 @@ void FilenameView::onProcessExited(QProcess* pProcess )
 	else
 	{
  		qDebug("normal exit");
- 		_pProvider->statusBar()->showMessage(QString("Finished viewing ") + filename, 4000);
+ 		_pProvider->statusBar()->showMessage(tr("Finished viewing ") + filename, 4000);
 		_seeCommands.erase(pProcess);
 		pProcess->deleteLater();
 	}
@@ -127,7 +127,7 @@ void FilenameView::on__pFilenameView_itemDoubleClicked(QListWidgetItem* pItem)
 	QString filename = pItem->text();
 	if (!isFileViewable(filename))
 	{
-		_pProvider->statusBar()->showMessage("Can't view file " + filename + ", it is not viewable",
+		_pProvider->statusBar()->showMessage(tr("Can't view file ") + filename + tr(", it is not viewable"),
 			5000);
 		return;
 	}
@@ -256,3 +256,8 @@ bool FilenameView::isFileViewable(QString filename)
 	return fileinfo.isReadable() && !fileinfo.isDir();
 }
 
+
+void FilenameView::setShowButtonEnabled(bool enabled)
+{
+	_pShowButton->setEnabled(enabled);
+}
