@@ -33,8 +33,7 @@ namespace NPlugin {
 class ScorePlugin : virtual public Plugin
 {
 public:
-	ScorePlugin();
-	~ScorePlugin();
+	virtual ~ScorePlugin() {};
 	/** @brief Returns the score of the handed packages for the currently active search.
 	  *
 	  * The scores are in [0..1] where 0.0f means the lowest and 1.0f the highest score.
