@@ -14,9 +14,15 @@
         <translation>Plugin um verwaiste Pakete zu suchen.</translation>
     </message>
     <message>
-        <location filename="../src/plugins/orphanplugin/orphanplugin.cpp" line="70"/>
         <source>This plugin supports to search for packages which are orphaned.
 It uses deborphan to implement the search</source>
+        <translation type="obsolete">Dieser Plugin ermöglicht die Suche nach verwaisten Paketen.
+Zur Realisierung der Suche wird deborphan verwendet.</translation>
+    </message>
+    <message>
+        <location filename="../src/plugins/orphanplugin/orphanplugin.cpp" line="70"/>
+        <source>This plugin supports to search for packages which are orphaned.
+It uses deborphan to implement the search.</source>
         <translation>Dieser Plugin ermöglicht die Suche nach verwaisten Paketen.
 Zur Realisierung der Suche wird deborphan verwendet.</translation>
     </message>
